@@ -2,25 +2,21 @@
 
 #ifndef STATIC_COORDGEN
 
-#ifdef IN_COORDGEN
 #ifdef WIN32
+#ifdef IN_COORDGEN
 #define EXPORT_COORDGEN __declspec(dllexport)
 #else
-#define EXPORT_COORDGEN __attribute__((visibility("default")))
-#endif
-
-#else
-
-#ifdef WIN32
 #define EXPORT_COORDGEN __declspec(dllimport)
-#else
-#define EXPORT_COORDGEN
-#endif
+#endif // IN_COORDGEN
 
-#endif
+#else
+
+#define EXPORT_COORDGEN __attribute__((visibility("default")))
+
+#endif // WIN32
 
 #else
 
 #define EXPORT_COORDGEN
 
-#endif
+#endif // STATIC_COORDGEN
