@@ -14,49 +14,59 @@ using namespace std;
 
 sketcherMinimizerAtom* sketcherMinimizerBond::startAtomCIPFirstNeighbor() const
 {
-    if (bondOrder != 2)
-        return NULL;
+    if (bondOrder != 2) {
+        return nullptr;
+    }
     sketcherMinimizerAtom* a = startAtom;
     if (a->neighbors.size() == 2) {
-        if (a->neighbors[0] == endAtom)
+        if (a->neighbors[0] == endAtom) {
             return a->neighbors[1];
-        else
+        } else {
             return a->neighbors[0];
+        }
     } else if (a->neighbors.size() == 3) {
         std::vector<sketcherMinimizerAtom*> ats;
-        foreach (sketcherMinimizerAtom* n, a->neighbors) {
-            if (n != endAtom)
+        for (sketcherMinimizerAtom* n : a->neighbors) {
+            if (n != endAtom) {
                 ats.push_back(n);
+            }
         }
-        if (ats.size() == 2)
+        if (ats.size() == 2) {
             return sketcherMinimizerAtom::CIPPriority(ats[0], ats[1],
                                                       startAtom);
-        return NULL;
-    } else
-        return NULL;
+        }
+        return nullptr;
+    } else {
+        return nullptr;
+    }
 }
 
 sketcherMinimizerAtom* sketcherMinimizerBond::endAtomCIPFirstNeighbor() const
 {
-    if (bondOrder != 2)
-        return NULL;
+    if (bondOrder != 2) {
+        return nullptr;
+    }
     sketcherMinimizerAtom* a = endAtom;
     if (a->neighbors.size() == 2) {
-        if (a->neighbors[0] == startAtom)
+        if (a->neighbors[0] == startAtom) {
             return a->neighbors[1];
-        else
+        } else {
             return a->neighbors[0];
+        }
     } else if (a->neighbors.size() == 3) {
         std::vector<sketcherMinimizerAtom*> ats;
-        foreach (sketcherMinimizerAtom* n, a->neighbors) {
-            if (n != startAtom)
+        for (sketcherMinimizerAtom* n : a->neighbors) {
+            if (n != startAtom) {
                 ats.push_back(n);
+            }
         }
-        if (ats.size() == 2)
+        if (ats.size() == 2) {
             return sketcherMinimizerAtom::CIPPriority(ats[0], ats[1], endAtom);
-        return NULL;
-    } else
-        return NULL;
+        }
+        return nullptr;
+    } else {
+        return nullptr;
+    }
 }
 
 void sketcherMinimizerBond::setAbsoluteStereoFromStereoInfo()
@@ -76,8 +86,9 @@ void sketcherMinimizerBond::setAbsoluteStereoFromStereoInfo()
             }
             bool settingIsZ =
                 (m_stereo.stereo == sketcherMinimizerBondStereoInfo::cis);
-            if (invert)
+            if (invert) {
                 settingIsZ = !settingIsZ;
+            }
             isZ = settingIsZ;
         }
     }
@@ -88,16 +99,20 @@ void sketcherMinimizerBond::setAbsoluteStereoFromStereoInfo()
 
 bool sketcherMinimizerBond::checkStereoChemistry() const
 {
-    if (!isStereo())
+    if (!isStereo()) {
         return true;
-    if (isInSmallRing())
+    }
+    if (isInSmallRing()) {
         return true;
+    }
     sketcherMinimizerAtom* firstCIPNeighborStart = startAtomCIPFirstNeighbor();
-    if (firstCIPNeighborStart == NULL)
+    if (firstCIPNeighborStart == nullptr) {
         return true;
+    }
     sketcherMinimizerAtom* firstCIPNeighborEnd = endAtomCIPFirstNeighbor();
-    if (firstCIPNeighborEnd == NULL)
+    if (firstCIPNeighborEnd == nullptr) {
         return true;
+    }
     return (sketcherMinimizerMaths::sameSide(
                 firstCIPNeighborStart->getCoordinates(),
                 firstCIPNeighborEnd->getCoordinates(),
@@ -108,8 +123,9 @@ bool sketcherMinimizerBond::checkStereoChemistry() const
 bool sketcherMinimizerBond::isInSmallRing() const
 {
     for (auto ring : rings) {
-        if (!ring->isMacrocycle())
+        if (!ring->isMacrocycle()) {
             return true;
+        }
     }
     return false;
 }
@@ -117,8 +133,9 @@ bool sketcherMinimizerBond::isInSmallRing() const
 bool sketcherMinimizerBond::isInMacrocycle() const
 {
     for (auto ring : rings) {
-        if (ring->isMacrocycle())
+        if (ring->isMacrocycle()) {
             return true;
+        }
     }
     return false;
 }
@@ -131,14 +148,18 @@ bool sketcherMinimizerBond::isTerminal() const
 
 bool sketcherMinimizerBond::isInterFragment() const
 {
-    if (getStartAtom()->getBonds().size() == 1)
+    if (getStartAtom()->getBonds().size() == 1) {
         return false;
-    if (getEndAtom()->getBonds().size() == 1)
+    }
+    if (getEndAtom()->getBonds().size() == 1) {
         return false;
-    if (sketcherMinimizerAtom::shareARing(getStartAtom(), getEndAtom()))
+    }
+    if (sketcherMinimizerAtom::shareARing(getStartAtom(), getEndAtom())) {
         return false;
-    if (isStereo())
+    }
+    if (isStereo()) {
         return false;
+    }
     return true;
 }
 
@@ -167,26 +188,24 @@ bool sketcherMinimizerBond::isStereo() const
     }
     sketcherMinimizerRing* ring =
         sketcherMinimizerAtom::shareARing(getStartAtom(), getEndAtom());
-    if (ring && !ring->isMacrocycle())
-        return false;
-    return true;
+    return !(ring && !ring->isMacrocycle());
 }
 
 void sketcherMinimizerBond::flip()
 {
-    int totalAtomsNumber = getStartAtom()->getMolecule()->getAtoms().size();
+    size_t totalAtomsNumber = getStartAtom()->getMolecule()->getAtoms().size();
     vector<sketcherMinimizerAtom*> atoms =
         getStartAtom()->getSubmolecule(getEndAtom());
-    if (atoms.size() > totalAtomsNumber * 0.5) {
+    if (atoms.size() > totalAtomsNumber / 2) {
         atoms = getEndAtom()->getSubmolecule(getStartAtom());
     }
     vector<sketcherMinimizerBond*> allBonds =
         getStartAtom()->getMolecule()->getBonds();
 
-    foreach (sketcherMinimizerAtom* atom, atoms) {
+    for (sketcherMinimizerAtom* atom : atoms) {
         sketcherMinimizerAtom::mirrorCoordinates(atom, this);
     }
-    foreach (sketcherMinimizerBond* bond, allBonds) {
+    for (sketcherMinimizerBond* bond : allBonds) {
         if (find(atoms.begin(), atoms.end(), bond->getStartAtom()) !=
                 atoms.end() &&
             find(atoms.begin(), atoms.end(), bond->getEndAtom()) !=
